@@ -61,7 +61,7 @@
 #define WILDABBR	"   "
 #endif /* !defined WILDABBR */
 
-static char		wildabbr[] = WILDABBR;
+static const char	wildabbr[] = WILDABBR;
 
 static const char	gmt[] = "GMT";
 
@@ -201,8 +201,8 @@ static int		lcl_is_set;
 static int		gmt_is_set;
 
 char *			tzname[2] = {
-	wildabbr,
-	wildabbr
+	(char *) wildabbr,
+	(char *) wildabbr
 };
 
 /*
@@ -254,8 +254,7 @@ settzname(void)
 	register struct state * const	sp = lclptr;
 	register int			i;
 
-	tzname[0] = wildabbr;
-	tzname[1] = wildabbr;
+	tzname[0] = tzname[1] = (char *) wildabbr;
 #ifdef USG_COMPAT
 	daylight = 0;
 	timezone = 0;
@@ -263,12 +262,10 @@ settzname(void)
 #ifdef ALTZONE
 	altzone = 0;
 #endif /* defined ALTZONE */
-#ifdef ALL_STATE
 	if (sp == NULL) {
-		tzname[0] = tzname[1] = gmt;
+		tzname[0] = tzname[1] = (char *) gmt;
 		return;
 	}
-#endif /* defined ALL_STATE */
 	/*
 	** And to get the latest zone names into tzname. . .
 	*/
@@ -339,17 +336,17 @@ tzload(register const char *name, register struct state *const sp,
 					4 * TZ_MAX_TIMES];
 	} u_t;
 #ifdef ALL_STATE
-	register u_t *			up;
-
-	up = (u_t *) calloc(1, sizeof *up);
-	if (up == NULL)
-		return -1;
+	register u_t * const		up = malloc(sizeof *up);
 #else /* !defined ALL_STATE */
 	u_t				u;
 	register u_t * const		up = &u;
 #endif /* !defined ALL_STATE */
 
 	sp->goback = sp->goahead = FALSE;
+
+	if (up == NULL)
+		return -1;
+
 	if (name == NULL && (name = TZDEFAULT) == NULL)
 		goto oops;
 	{
@@ -1013,6 +1010,7 @@ tzparse(const char *name, register struct state *const sp,
 			sp->ttis[1].tt_gmtoff = -stdoffset;
 			sp->ttis[1].tt_isdst = 0;
 			sp->ttis[1].tt_abbrind = 0;
+			sp->defaulttype = 0;
 			timecnt = 0;
 			janfirst = 0;
 			yearlim = EPOCH_YEAR + YEARSPERREPEAT;
@@ -1138,6 +1136,7 @@ tzparse(const char *name, register struct state *const sp,
 			sp->ttis[1].tt_isdst = TRUE;
 			sp->ttis[1].tt_abbrind = stdlen + 1;
 			sp->typecnt = 2;
+			sp->defaulttype = 0;
 		}
 	} else {
 		dstlen = 0;
@@ -1147,6 +1146,7 @@ tzparse(const char *name, register struct state *const sp,
 		sp->ttis[0].tt_gmtoff = -stdoffset;
 		sp->ttis[0].tt_isdst = 0;
 		sp->ttis[0].tt_abbrind = 0;
+		sp->defaulttype = 0;
 	}
 	sp->charcnt = stdlen + 1;
 	if (dstlen != 0)
@@ -1187,7 +1187,7 @@ tzsetwall(void)
 
 #ifdef ALL_STATE
 	if (lclptr == NULL) {
-		lclptr = calloc(1, sizeof *lclptr);
+		lclptr = malloc(sizeof *lclptr);
 		if (lclptr == NULL) {
 			settzname();	/* all we can do */
 			return;
@@ -1218,7 +1218,7 @@ tzset(void)
 
 #ifdef ALL_STATE
 	if (lclptr == NULL) {
-		lclptr = calloc(1, sizeof *lclptr);
+		lclptr = malloc(sizeof *lclptr);
 		if (lclptr == NULL) {
 			settzname();	/* all we can do */
 			return;
@@ -1263,10 +1263,8 @@ localsub(const time_t *const timep, const int_fast32_t offset,
 	const time_t			t = *timep;
 
 	sp = lclptr;
-#ifdef ALL_STATE
 	if (sp == NULL)
 		return gmtsub(timep, offset, tmp);
-#endif /* defined ALL_STATE */
 	if ((sp->goback && t < sp->ats[0]) ||
 		(sp->goahead && t > sp->ats[sp->timecnt - 1])) {
 			time_t			newt = t;
@@ -1360,9 +1358,9 @@ gmtsub(const time_t *const timep, const int_fast32_t offset,
 	if (!gmt_is_set) {
 		gmt_is_set = TRUE;
 #ifdef ALL_STATE
-		gmtptr = calloc(1, sizeof *gmtptr);
-		if (gmtptr != NULL)
+		gmtptr = malloc(sizeof *gmtptr);
 #endif /* defined ALL_STATE */
+		if (gmtptr != NULL)
 			gmtload(gmtptr);
 	}
 	result = timesub(timep, offset, gmtptr, tmp);
@@ -1372,18 +1370,7 @@ gmtsub(const time_t *const timep, const int_fast32_t offset,
 	** "UT+xxxx" or "UT-xxxx" if offset is non-zero,
 	** but this is no time for a treasure hunt.
 	*/
-	if (offset != 0)
-		tmp->TM_ZONE = wildabbr;
-	else {
-#ifdef ALL_STATE
-		if (gmtptr == NULL)
-			tmp->TM_ZONE = gmt;
-		else	tmp->TM_ZONE = gmtptr->chars;
-#endif /* defined ALL_STATE */
-#ifndef ALL_STATE
-		tmp->TM_ZONE = gmtptr->chars;
-#endif /* State Farm */
-	}
+	tmp->TM_ZONE = offset ? wildabbr : gmtptr ? gmtptr->chars : gmt;
 #endif /* defined TM_ZONE */
 	return result;
 }
@@ -1443,12 +1430,7 @@ timesub(const time_t *const timep, const int_fast32_t offset,
 
 	corr = 0;
 	hit = 0;
-#ifdef ALL_STATE
 	i = (sp == NULL) ? 0 : sp->leapcnt;
-#endif /* defined ALL_STATE */
-#ifndef ALL_STATE
-	i = sp->leapcnt;
-#endif /* State Farm */
 	while (--i >= 0) {
 		lp = &sp->lsis[i];
 		if (*timep >= lp->ls_trans) {
@@ -1822,10 +1804,8 @@ time2sub(struct tm *const tmp,
 		*/
 		sp = (const struct state *)
 			((funcp == localsub) ? lclptr : gmtptr);
-#ifdef ALL_STATE
 		if (sp == NULL)
 			return WRONG;
-#endif /* defined ALL_STATE */
 		for (i = sp->typecnt - 1; i >= 0; --i) {
 			if (sp->ttis[i].tt_isdst != yourtm.tm_isdst)
 				continue;
@@ -1898,17 +1878,15 @@ time1(struct tm *const tmp,
 	if (tmp->tm_isdst > 1)
 		tmp->tm_isdst = 1;
 	t = time2(tmp, funcp, offset, &okay);
-#ifdef PCTS
-	/*
-	** PCTS code courtesy Grant Sullivan.
-	*/
 	if (okay)
 		return t;
 	if (tmp->tm_isdst < 0)
+#ifdef PCTS
+		/*
+		** POSIX Conformance Test Suite code courtesy Grant Sullivan.
+		*/
 		tmp->tm_isdst = 0;	/* reset to std and try again */
-#endif /* defined PCTS */
-#ifndef PCTS
-	if (okay || tmp->tm_isdst < 0)
+#else
 		return t;
 #endif /* !defined PCTS */
 	/*
@@ -1918,10 +1896,8 @@ time1(struct tm *const tmp,
 	** type they need.
 	*/
 	sp = (const struct state *) ((funcp == localsub) ?  lclptr : gmtptr);
-#ifdef ALL_STATE
 	if (sp == NULL)
 		return WRONG;
-#endif /* defined ALL_STATE */
 	for (i = 0; i < sp->typecnt; ++i)
 		seen[i] = FALSE;
 	nseen = 0;
